pilas.comportamientos

Package pilas :: Module comportamientos |
[hide private]
[frames] | no frames]

# Module comportamientos

source code

Classes | [hide private]
| Comportamiento Representa un comportamiento (estrategia) que se puede anexar a un actor.
| Girar Hace girar constantemente al actor respecto de su eje de forma relativa.
| Saltar Realiza un salto, cambiando los atributos 'y'.
| Avanzar Desplaza al actor en la dirección y sentido indicado por una rotación.
| Proyectil Hace que un actor se comporte como un proyectil.

Variables | [hide private]
| __package__ = ``'``pilas``'``